Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterParameterManagerServer(s grpc.ServiceRegistrar, srv ParameterManagerServer)
- type CreateParameterRequest
- func (*CreateParameterRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateParameterRequest) GetParameter() *Parameter
- func (x *CreateParameterRequest) GetParameterId() string
- func (x *CreateParameterRequest) GetParent() string
- func (x *CreateParameterRequest) GetRequestId() string
- func (*CreateParameterRequest) ProtoMessage()
- func (x *CreateParameterRequest) ProtoReflect() protoreflect.Message
- func (x *CreateParameterRequest) Reset()
- func (x *CreateParameterRequest) String() string
- type CreateParameterVersionRequest
- func (*CreateParameterVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateParameterVersionRequest) GetParameterVersion() *ParameterVersion
- func (x *CreateParameterVersionRequest) GetParameterVersionId() string
- func (x *CreateParameterVersionRequest) GetParent() string
- func (x *CreateParameterVersionRequest) GetRequestId() string
- func (*CreateParameterVersionRequest) ProtoMessage()
- func (x *CreateParameterVersionRequest) ProtoReflect() protoreflect.Message
- func (x *CreateParameterVersionRequest) Reset()
- func (x *CreateParameterVersionRequest) String() string
- type DeleteParameterRequest
- func (*DeleteParameterRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteParameterRequest) GetName() string
- func (x *DeleteParameterRequest) GetRequestId() string
- func (*DeleteParameterRequest) ProtoMessage()
- func (x *DeleteParameterRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteParameterRequest) Reset()
- func (x *DeleteParameterRequest) String() string
- type DeleteParameterVersionRequest
- func (*DeleteParameterVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteParameterVersionRequest) GetName() string
- func (x *DeleteParameterVersionRequest) GetRequestId() string
- func (*DeleteParameterVersionRequest) ProtoMessage()
- func (x *DeleteParameterVersionRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteParameterVersionRequest) Reset()
- func (x *DeleteParameterVersionRequest) String() string
- type GetParameterRequest
- func (*GetParameterRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetParameterRequest) GetName() string
- func (*GetParameterRequest) ProtoMessage()
- func (x *GetParameterRequest) ProtoReflect() protoreflect.Message
- func (x *GetParameterRequest) Reset()
- func (x *GetParameterRequest) String() string
- type GetParameterVersionRequest
- func (*GetParameterVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetParameterVersionRequest) GetName() string
- func (x *GetParameterVersionRequest) GetView() View
- func (*GetParameterVersionRequest) ProtoMessage()
- func (x *GetParameterVersionRequest) ProtoReflect() protoreflect.Message
- func (x *GetParameterVersionRequest) Reset()
- func (x *GetParameterVersionRequest) String() string
- type ListParameterVersionsRequest
- func (*ListParameterVersionsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListParameterVersionsRequest) GetFilter() string
- func (x *ListParameterVersionsRequest) GetOrderBy() string
- func (x *ListParameterVersionsRequest) GetPageSize() int32
- func (x *ListParameterVersionsRequest) GetPageToken() string
- func (x *ListParameterVersionsRequest) GetParent() string
- func (*ListParameterVersionsRequest) ProtoMessage()
- func (x *ListParameterVersionsRequest) ProtoReflect() protoreflect.Message
- func (x *ListParameterVersionsRequest) Reset()
- func (x *ListParameterVersionsRequest) String() string
- type ListParameterVersionsResponse
- func (*ListParameterVersionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListParameterVersionsResponse) GetNextPageToken() string
- func (x *ListParameterVersionsResponse) GetParameterVersions() []*ParameterVersion
- func (x *ListParameterVersionsResponse) GetUnreachable() []string
- func (*ListParameterVersionsResponse) ProtoMessage()
- func (x *ListParameterVersionsResponse) ProtoReflect() protoreflect.Message
- func (x *ListParameterVersionsResponse) Reset()
- func (x *ListParameterVersionsResponse) String() string
- type ListParametersRequest
- func (*ListParametersRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListParametersRequest) GetFilter() string
- func (x *ListParametersRequest) GetOrderBy() string
- func (x *ListParametersRequest) GetPageSize() int32
- func (x *ListParametersRequest) GetPageToken() string
- func (x *ListParametersRequest) GetParent() string
- func (*ListParametersRequest) ProtoMessage()
- func (x *ListParametersRequest) ProtoReflect() protoreflect.Message
- func (x *ListParametersRequest) Reset()
- func (x *ListParametersRequest) String() string
- type ListParametersResponse
- func (*ListParametersResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListParametersResponse) GetNextPageToken() string
- func (x *ListParametersResponse) GetParameters() []*Parameter
- func (x *ListParametersResponse) GetUnreachable() []string
- func (*ListParametersResponse) ProtoMessage()
- func (x *ListParametersResponse) ProtoReflect() protoreflect.Message
- func (x *ListParametersResponse) Reset()
- func (x *ListParametersResponse) String() string
- type Parameter
- func (*Parameter) Descriptor() ([]byte, []int)deprecated
- func (x *Parameter) GetCreateTime() *timestamppb.Timestamp
- func (x *Parameter) GetFormat() ParameterFormat
- func (x *Parameter) GetKmsKey() string
- func (x *Parameter) GetLabels() map[string]string
- func (x *Parameter) GetName() string
- func (x *Parameter) GetPolicyMember() *iampb.ResourcePolicyMember
- func (x *Parameter) GetUpdateTime() *timestamppb.Timestamp
- func (*Parameter) ProtoMessage()
- func (x *Parameter) ProtoReflect() protoreflect.Message
- func (x *Parameter) Reset()
- func (x *Parameter) String() string
- type ParameterFormat
- func (ParameterFormat) Descriptor() protoreflect.EnumDescriptor
- func (x ParameterFormat) Enum() *ParameterFormat
- func (ParameterFormat) EnumDescriptor() ([]byte, []int)deprecated
- func (x ParameterFormat) Number() protoreflect.EnumNumber
- func (x ParameterFormat) String() string
- func (ParameterFormat) Type() protoreflect.EnumType
- type ParameterManagerClient
- type ParameterManagerServer
- type ParameterVersion
- func (*ParameterVersion) Descriptor() ([]byte, []int)deprecated
- func (x *ParameterVersion) GetCreateTime() *timestamppb.Timestamp
- func (x *ParameterVersion) GetDisabled() bool
- func (x *ParameterVersion) GetKmsKeyVersion() string
- func (x *ParameterVersion) GetName() string
- func (x *ParameterVersion) GetPayload() *ParameterVersionPayload
- func (x *ParameterVersion) GetUpdateTime() *timestamppb.Timestamp
- func (*ParameterVersion) ProtoMessage()
- func (x *ParameterVersion) ProtoReflect() protoreflect.Message
- func (x *ParameterVersion) Reset()
- func (x *ParameterVersion) String() string
- type ParameterVersionPayload
- func (*ParameterVersionPayload) Descriptor() ([]byte, []int)deprecated
- func (x *ParameterVersionPayload) GetData() []byte
- func (*ParameterVersionPayload) ProtoMessage()
- func (x *ParameterVersionPayload) ProtoReflect() protoreflect.Message
- func (x *ParameterVersionPayload) Reset()
- func (x *ParameterVersionPayload) String() string
- type RenderParameterVersionRequest
- func (*RenderParameterVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *RenderParameterVersionRequest) GetName() string
- func (*RenderParameterVersionRequest) ProtoMessage()
- func (x *RenderParameterVersionRequest) ProtoReflect() protoreflect.Message
- func (x *RenderParameterVersionRequest) Reset()
- func (x *RenderParameterVersionRequest) String() string
- type RenderParameterVersionResponse
- func (*RenderParameterVersionResponse) Descriptor() ([]byte, []int)deprecated
- func (x *RenderParameterVersionResponse) GetParameterVersion() string
- func (x *RenderParameterVersionResponse) GetPayload() *ParameterVersionPayload
- func (x *RenderParameterVersionResponse) GetRenderedPayload() []byte
- func (*RenderParameterVersionResponse) ProtoMessage()
- func (x *RenderParameterVersionResponse) ProtoReflect() protoreflect.Message
- func (x *RenderParameterVersionResponse) Reset()
- func (x *RenderParameterVersionResponse) String() string
- type UnimplementedParameterManagerServer
- func (UnimplementedParameterManagerServer) CreateParameter(context.Context, *CreateParameterRequest) (*Parameter, error)
- func (UnimplementedParameterManagerServer) CreateParameterVersion(context.Context, *CreateParameterVersionRequest) (*ParameterVersion, error)
- func (UnimplementedParameterManagerServer) DeleteParameter(context.Context, *DeleteParameterRequest) (*emptypb.Empty, error)
- func (UnimplementedParameterManagerServer) DeleteParameterVersion(context.Context, *DeleteParameterVersionRequest) (*emptypb.Empty, error)
- func (UnimplementedParameterManagerServer) GetParameter(context.Context, *GetParameterRequest) (*Parameter, error)
- func (UnimplementedParameterManagerServer) GetParameterVersion(context.Context, *GetParameterVersionRequest) (*ParameterVersion, error)
- func (UnimplementedParameterManagerServer) ListParameterVersions(context.Context, *ListParameterVersionsRequest) (*ListParameterVersionsResponse, error)
- func (UnimplementedParameterManagerServer) ListParameters(context.Context, *ListParametersRequest) (*ListParametersResponse, error)
- func (UnimplementedParameterManagerServer) RenderParameterVersion(context.Context, *RenderParameterVersionRequest) (*RenderParameterVersionResponse, error)
- func (UnimplementedParameterManagerServer) UpdateParameter(context.Context, *UpdateParameterRequest) (*Parameter, error)
- func (UnimplementedParameterManagerServer) UpdateParameterVersion(context.Context, *UpdateParameterVersionRequest) (*ParameterVersion, error)
- type UnsafeParameterManagerServer
- type UpdateParameterRequest
- func (*UpdateParameterRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateParameterRequest) GetParameter() *Parameter
- func (x *UpdateParameterRequest) GetRequestId() string
- func (x *UpdateParameterRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateParameterRequest) ProtoMessage()
- func (x *UpdateParameterRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateParameterRequest) Reset()
- func (x *UpdateParameterRequest) String() string
- type UpdateParameterVersionRequest
- func (*UpdateParameterVersionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateParameterVersionRequest) GetParameterVersion() *ParameterVersion
- func (x *UpdateParameterVersionRequest) GetRequestId() string
- func (x *UpdateParameterVersionRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateParameterVersionRequest) ProtoMessage()
- func (x *UpdateParameterVersionRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateParameterVersionRequest) Reset()
- func (x *UpdateParameterVersionRequest) String() string
- type View
Constants ¶
const ( ParameterManager_ListParameters_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/ListParameters" ParameterManager_GetParameter_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/GetParameter" ParameterManager_CreateParameter_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/CreateParameter" ParameterManager_UpdateParameter_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/UpdateParameter" ParameterManager_DeleteParameter_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/DeleteParameter" ParameterManager_ListParameterVersions_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/ListParameterVersions" ParameterManager_GetParameterVersion_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/GetParameterVersion" ParameterManager_RenderParameterVersion_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/RenderParameterVersion" ParameterManager_CreateParameterVersion_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/CreateParameterVersion" ParameterManager_UpdateParameterVersion_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/UpdateParameterVersion" ParameterManager_DeleteParameterVersion_FullMethodName = "/google.cloud.parametermanager.v1.ParameterManager/DeleteParameterVersion" )
Variables ¶
var ( ParameterFormat_name = map[int32]string{ 0: "PARAMETER_FORMAT_UNSPECIFIED", 1: "UNFORMATTED", 2: "YAML", 3: "JSON", } ParameterFormat_value = map[string]int32{ "PARAMETER_FORMAT_UNSPECIFIED": 0, "UNFORMATTED": 1, "YAML": 2, "JSON": 3, } )
Enum value maps for ParameterFormat.
var ( View_name = map[int32]string{ 0: "VIEW_UNSPECIFIED", 1: "BASIC", 2: "FULL", } View_value = map[string]int32{ "VIEW_UNSPECIFIED": 0, "BASIC": 1, "FULL": 2, } )
Enum value maps for View.
var File_google_cloud_parametermanager_v1_service_proto protoreflect.FileDescriptor
var ParameterManager_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.parametermanager.v1.ParameterManager", HandlerType: (*ParameterManagerServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListParameters", Handler: _ParameterManager_ListParameters_Handler, }, { MethodName: "GetParameter", Handler: _ParameterManager_GetParameter_Handler, }, { MethodName: "CreateParameter", Handler: _ParameterManager_CreateParameter_Handler, }, { MethodName: "UpdateParameter", Handler: _ParameterManager_UpdateParameter_Handler, }, { MethodName: "DeleteParameter", Handler: _ParameterManager_DeleteParameter_Handler, }, { MethodName: "ListParameterVersions", Handler: _ParameterManager_ListParameterVersions_Handler, }, { MethodName: "GetParameterVersion", Handler: _ParameterManager_GetParameterVersion_Handler, }, { MethodName: "RenderParameterVersion", Handler: _ParameterManager_RenderParameterVersion_Handler, }, { MethodName: "CreateParameterVersion", Handler: _ParameterManager_CreateParameterVersion_Handler, }, { MethodName: "UpdateParameterVersion", Handler: _ParameterManager_UpdateParameterVersion_Handler, }, { MethodName: "DeleteParameterVersion", Handler: _ParameterManager_DeleteParameterVersion_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/parametermanager/v1/service.proto", }
ParameterManager_ServiceDesc is the grpc.ServiceDesc for ParameterManager service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterParameterManagerServer ¶
func RegisterParameterManagerServer(s grpc.ServiceRegistrar, srv ParameterManagerServer)
Types ¶
type CreateParameterRequest ¶
type CreateParameterRequest struct {
// Required. Value for parent in the format
// `projects/*/locations/*`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. Id of the Parameter resource
ParameterId string `protobuf:"bytes,2,opt,name=parameter_id,json=parameterId,proto3" json:"parameter_id,omitempty"`
// Required. The Parameter resource being created
Parameter *Parameter `protobuf:"bytes,3,opt,name=parameter,proto3" json:"parameter,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique
// request ID so that if you must retry your request, the server will know to
// ignore the request if it has already been completed. The server will
// guarantee that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and the
// request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Message for creating a Parameter
func (*CreateParameterRequest) Descriptor
deprecated
func (*CreateParameterRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateParameterRequest.ProtoReflect.Descriptor instead.
func (*CreateParameterRequest) GetParameter ¶
func (x *CreateParameterRequest) GetParameter() *Parameter
func (*CreateParameterRequest) GetParameterId ¶
func (x *CreateParameterRequest) GetParameterId() string
func (*CreateParameterRequest) GetParent ¶
func (x *CreateParameterRequest) GetParent() string
func (*CreateParameterRequest) GetRequestId ¶
func (x *CreateParameterRequest) GetRequestId() string
func (*CreateParameterRequest) ProtoMessage ¶
func (*CreateParameterRequest) ProtoMessage()
func (*CreateParameterRequest) ProtoReflect ¶
func (x *CreateParameterRequest) ProtoReflect() protoreflect.Message
func (*CreateParameterRequest) Reset ¶
func (x *CreateParameterRequest) Reset()
func (*CreateParameterRequest) String ¶
func (x *CreateParameterRequest) String() string
type CreateParameterVersionRequest ¶
type CreateParameterVersionRequest struct {
// Required. Value for parent in the format
// `projects/*/locations/*/parameters/*`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. Id of the ParameterVersion resource
ParameterVersionId string `protobuf:"bytes,2,opt,name=parameter_version_id,json=parameterVersionId,proto3" json:"parameter_version_id,omitempty"`
// Required. The ParameterVersion resource being created
ParameterVersion *ParameterVersion `protobuf:"bytes,3,opt,name=parameter_version,json=parameterVersion,proto3" json:"parameter_version,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique
// request ID so that if you must retry your request, the server will know to
// ignore the request if it has already been completed. The server will
// guarantee that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and the
// request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,4,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Message for creating a ParameterVersion
func (*CreateParameterVersionRequest) Descriptor
deprecated
func (*CreateParameterVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateParameterVersionRequest.ProtoReflect.Descriptor instead.
func (*CreateParameterVersionRequest) GetParameterVersion ¶
func (x *CreateParameterVersionRequest) GetParameterVersion() *ParameterVersion
func (*CreateParameterVersionRequest) GetParameterVersionId ¶
func (x *CreateParameterVersionRequest) GetParameterVersionId() string
func (*CreateParameterVersionRequest) GetParent ¶
func (x *CreateParameterVersionRequest) GetParent() string
func (*CreateParameterVersionRequest) GetRequestId ¶
func (x *CreateParameterVersionRequest) GetRequestId() string
func (*CreateParameterVersionRequest) ProtoMessage ¶
func (*CreateParameterVersionRequest) ProtoMessage()
func (*CreateParameterVersionRequest) ProtoReflect ¶
func (x *CreateParameterVersionRequest) ProtoReflect() protoreflect.Message
func (*CreateParameterVersionRequest) Reset ¶
func (x *CreateParameterVersionRequest) Reset()
func (*CreateParameterVersionRequest) String ¶
func (x *CreateParameterVersionRequest) String() string
type DeleteParameterRequest ¶
type DeleteParameterRequest struct {
// Required. Name of the resource in the format
// `projects/*/locations/*/parameters/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique
// request ID so that if you must retry your request, the server will know to
// ignore the request if it has already been completed. The server will
// guarantee that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and the
// request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Message for deleting a Parameter
func (*DeleteParameterRequest) Descriptor
deprecated
func (*DeleteParameterRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteParameterRequest.ProtoReflect.Descriptor instead.
func (*DeleteParameterRequest) GetName ¶
func (x *DeleteParameterRequest) GetName() string
func (*DeleteParameterRequest) GetRequestId ¶
func (x *DeleteParameterRequest) GetRequestId() string
func (*DeleteParameterRequest) ProtoMessage ¶
func (*DeleteParameterRequest) ProtoMessage()
func (*DeleteParameterRequest) ProtoReflect ¶
func (x *DeleteParameterRequest) ProtoReflect() protoreflect.Message
func (*DeleteParameterRequest) Reset ¶
func (x *DeleteParameterRequest) Reset()
func (*DeleteParameterRequest) String ¶
func (x *DeleteParameterRequest) String() string
type DeleteParameterVersionRequest ¶
type DeleteParameterVersionRequest struct {
// Required. Name of the resource in the format
// `projects/*/locations/*/parameters/*/versions/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique
// request ID so that if you must retry your request, the server will know to
// ignore the request if it has already been completed. The server will
// guarantee that for at least 60 minutes after the first request.
//
// For example, consider a situation where you make an initial request and the
// request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,2,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Message for deleting a ParameterVersion
func (*DeleteParameterVersionRequest) Descriptor
deprecated
func (*DeleteParameterVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteParameterVersionRequest.ProtoReflect.Descriptor instead.
func (*DeleteParameterVersionRequest) GetName ¶
func (x *DeleteParameterVersionRequest) GetName() string
func (*DeleteParameterVersionRequest) GetRequestId ¶
func (x *DeleteParameterVersionRequest) GetRequestId() string
func (*DeleteParameterVersionRequest) ProtoMessage ¶
func (*DeleteParameterVersionRequest) ProtoMessage()
func (*DeleteParameterVersionRequest) ProtoReflect ¶
func (x *DeleteParameterVersionRequest) ProtoReflect() protoreflect.Message
func (*DeleteParameterVersionRequest) Reset ¶
func (x *DeleteParameterVersionRequest) Reset()
func (*DeleteParameterVersionRequest) String ¶
func (x *DeleteParameterVersionRequest) String() string
type GetParameterRequest ¶
type GetParameterRequest struct {
// Required. Name of the resource in the format
// `projects/*/locations/*/parameters/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Message for getting a Parameter
func (*GetParameterRequest) Descriptor
deprecated
func (*GetParameterRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetParameterRequest.ProtoReflect.Descriptor instead.
func (*GetParameterRequest) GetName ¶
func (x *GetParameterRequest) GetName() string
func (*GetParameterRequest) ProtoMessage ¶
func (*GetParameterRequest) ProtoMessage()
func (*GetParameterRequest) ProtoReflect ¶
func (x *GetParameterRequest) ProtoReflect() protoreflect.Message
func (*GetParameterRequest) Reset ¶
func (x *GetParameterRequest) Reset()
func (*GetParameterRequest) String ¶
func (x *GetParameterRequest) String() string
type GetParameterVersionRequest ¶
type GetParameterVersionRequest struct {
// Required. Name of the resource in the format
// `projects/*/locations/*/parameters/*/versions/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Optional. View of the ParameterVersion.
// In the default FULL view, all metadata & payload associated with the
// ParameterVersion will be returned.
View View `protobuf:"varint,6,opt,name=view,proto3,enum=google.cloud.parametermanager.v1.View" json:"view,omitempty"`
// contains filtered or unexported fields
}
Message for getting a ParameterVersion
func (*GetParameterVersionRequest) Descriptor
deprecated
func (*GetParameterVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetParameterVersionRequest.ProtoReflect.Descriptor instead.
func (*GetParameterVersionRequest) GetName ¶
func (x *GetParameterVersionRequest) GetName() string
func (*GetParameterVersionRequest) GetView ¶
func (x *GetParameterVersionRequest) GetView() View
func (*GetParameterVersionRequest) ProtoMessage ¶
func (*GetParameterVersionRequest) ProtoMessage()
func (*GetParameterVersionRequest) ProtoReflect ¶
func (x *GetParameterVersionRequest) ProtoReflect() protoreflect.Message
func (*GetParameterVersionRequest) Reset ¶
func (x *GetParameterVersionRequest) Reset()
func (*GetParameterVersionRequest) String ¶
func (x *GetParameterVersionRequest) String() string
type ListParameterVersionsRequest ¶
type ListParameterVersionsRequest struct {
// Required. Parent value for ListParameterVersionsRequest in the format
// `projects/*/locations/*/parameters/*`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Optional. Requested page size. Server may return fewer items than
// requested. If unspecified, server will pick an appropriate default.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// Optional. A token identifying a page of results the server should return.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// Optional. Filtering results
Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
// Optional. Hint for how to order the results
OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
// contains filtered or unexported fields
}
Message for requesting list of ParameterVersions
func (*ListParameterVersionsRequest) Descriptor
deprecated
func (*ListParameterVersionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListParameterVersionsRequest.ProtoReflect.Descriptor instead.
func (*ListParameterVersionsRequest) GetFilter ¶
func (x *ListParameterVersionsRequest) GetFilter() string
func (*ListParameterVersionsRequest) GetOrderBy ¶
func (x *ListParameterVersionsRequest) GetOrderBy() string
func (*ListParameterVersionsRequest) GetPageSize ¶
func (x *ListParameterVersionsRequest) GetPageSize() int32
func (*ListParameterVersionsRequest) GetPageToken ¶
func (x *ListParameterVersionsRequest) GetPageToken() string
func (*ListParameterVersionsRequest) GetParent ¶
func (x *ListParameterVersionsRequest) GetParent() string
func (*ListParameterVersionsRequest) ProtoMessage ¶
func (*ListParameterVersionsRequest) ProtoMessage()
func (*ListParameterVersionsRequest) ProtoReflect ¶
func (x *ListParameterVersionsRequest) ProtoReflect() protoreflect.Message
func (*ListParameterVersionsRequest) Reset ¶
func (x *ListParameterVersionsRequest) Reset()
func (*ListParameterVersionsRequest) String ¶
func (x *ListParameterVersionsRequest) String() string
type ListParameterVersionsResponse ¶
type ListParameterVersionsResponse struct {
// The list of ParameterVersions
ParameterVersions []*ParameterVersion `protobuf:"bytes,1,rep,name=parameter_versions,json=parameterVersions,proto3" json:"parameter_versions,omitempty"`
// A token identifying a page of results the server should return.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// Unordered list. Locations that could not be reached.
Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
// contains filtered or unexported fields
}
Message for response to listing ParameterVersions
func (*ListParameterVersionsResponse) Descriptor
deprecated
func (*ListParameterVersionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListParameterVersionsResponse.ProtoReflect.Descriptor instead.
func (*ListParameterVersionsResponse) GetNextPageToken ¶
func (x *ListParameterVersionsResponse) GetNextPageToken() string
func (*ListParameterVersionsResponse) GetParameterVersions ¶
func (x *ListParameterVersionsResponse) GetParameterVersions() []*ParameterVersion
func (*ListParameterVersionsResponse) GetUnreachable ¶
func (x *ListParameterVersionsResponse) GetUnreachable() []string
func (*ListParameterVersionsResponse) ProtoMessage ¶
func (*ListParameterVersionsResponse) ProtoMessage()
func (*ListParameterVersionsResponse) ProtoReflect ¶
func (x *ListParameterVersionsResponse) ProtoReflect() protoreflect.Message
func (*ListParameterVersionsResponse) Reset ¶
func (x *ListParameterVersionsResponse) Reset()
func (*ListParameterVersionsResponse) String ¶
func (x *ListParameterVersionsResponse) String() string
type ListParametersRequest ¶
type ListParametersRequest struct {
// Required. Parent value for ListParametersRequest in the format
// `projects/*/locations/*`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Optional. Requested page size. Server may return fewer items than
// requested. If unspecified, server will pick an appropriate default.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// Optional. A token identifying a page of results the server should return.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// Optional. Filtering results
Filter string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
// Optional. Hint for how to order the results
OrderBy string `protobuf:"bytes,5,opt,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
// contains filtered or unexported fields
}
Message for requesting list of Parameters
func (*ListParametersRequest) Descriptor
deprecated
func (*ListParametersRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListParametersRequest.ProtoReflect.Descriptor instead.
func (*ListParametersRequest) GetFilter ¶
func (x *ListParametersRequest) GetFilter() string
func (*ListParametersRequest) GetOrderBy ¶
func (x *ListParametersRequest) GetOrderBy() string
func (*ListParametersRequest) GetPageSize ¶
func (x *ListParametersRequest) GetPageSize() int32
func (*ListParametersRequest) GetPageToken ¶
func (x *ListParametersRequest) GetPageToken() string
func (*ListParametersRequest) GetParent ¶
func (x *ListParametersRequest) GetParent() string
func (*ListParametersRequest) ProtoMessage ¶
func (*ListParametersRequest) ProtoMessage()
func (*ListParametersRequest) ProtoReflect ¶
func (x *ListParametersRequest) ProtoReflect() protoreflect.Message
func (*ListParametersRequest) Reset ¶
func (x *ListParametersRequest) Reset()
func (*ListParametersRequest) String ¶
func (x *ListParametersRequest) String() string
type ListParametersResponse ¶
type ListParametersResponse struct {
// The list of Parameters
Parameters []*Parameter `protobuf:"bytes,1,rep,name=parameters,proto3" json:"parameters,omitempty"`
// A token identifying a page of results the server should return.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// Unordered list. Locations that could not be reached.
Unreachable []string `protobuf:"bytes,3,rep,name=unreachable,proto3" json:"unreachable,omitempty"`
// contains filtered or unexported fields
}
Message for response to listing Parameters
func (*ListParametersResponse) Descriptor
deprecated
func (*ListParametersResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListParametersResponse.ProtoReflect.Descriptor instead.
func (*ListParametersResponse) GetNextPageToken ¶
func (x *ListParametersResponse) GetNextPageToken() string
func (*ListParametersResponse) GetParameters ¶
func (x *ListParametersResponse) GetParameters() []*Parameter
func (*ListParametersResponse) GetUnreachable ¶
func (x *ListParametersResponse) GetUnreachable() []string
func (*ListParametersResponse) ProtoMessage ¶
func (*ListParametersResponse) ProtoMessage()
func (*ListParametersResponse) ProtoReflect ¶
func (x *ListParametersResponse) ProtoReflect() protoreflect.Message
func (*ListParametersResponse) Reset ¶
func (x *ListParametersResponse) Reset()
func (*ListParametersResponse) String ¶
func (x *ListParametersResponse) String() string
type Parameter ¶
type Parameter struct {
// Identifier. [Output only] The resource name of the Parameter in the format
// `projects/*/locations/*/parameters/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Output only. [Output only] Create time stamp
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. [Output only] Update time stamp
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Optional. Labels as key value pairs
Labels map[string]string `` /* 153-byte string literal not displayed */
// Optional. Specifies the format of a Parameter.
Format ParameterFormat `protobuf:"varint,5,opt,name=format,proto3,enum=google.cloud.parametermanager.v1.ParameterFormat" json:"format,omitempty"`
// Output only. [Output-only] policy member strings of a Google Cloud
// resource.
PolicyMember *iampb.ResourcePolicyMember `protobuf:"bytes,6,opt,name=policy_member,json=policyMember,proto3" json:"policy_member,omitempty"`
// Optional. Customer managed encryption key (CMEK) to use for encrypting the
// Parameter Versions. If not set, the default Google-managed encryption key
// will be used. Cloud KMS CryptoKeys must reside in the same location as the
// Parameter. The expected format is
// `projects/*/locations/*/keyRings/*/cryptoKeys/*`.
KmsKey *string `protobuf:"bytes,7,opt,name=kms_key,json=kmsKey,proto3,oneof" json:"kms_key,omitempty"`
// contains filtered or unexported fields
}
Message describing Parameter resource
func (*Parameter) Descriptor
deprecated
func (*Parameter) GetCreateTime ¶
func (x *Parameter) GetCreateTime() *timestamppb.Timestamp
func (*Parameter) GetFormat ¶
func (x *Parameter) GetFormat() ParameterFormat
func (*Parameter) GetPolicyMember ¶
func (x *Parameter) GetPolicyMember() *iampb.ResourcePolicyMember
func (*Parameter) GetUpdateTime ¶
func (x *Parameter) GetUpdateTime() *timestamppb.Timestamp
func (*Parameter) ProtoMessage ¶
func (*Parameter) ProtoMessage()
func (*Parameter) ProtoReflect ¶
func (x *Parameter) ProtoReflect() protoreflect.Message
type ParameterFormat ¶
type ParameterFormat int32
Option to specify the format of a Parameter resource (UNFORMATTED / YAML / JSON). This option is user specified at the time of creation of the resource and is immutable.
const ( // The default / unset value. // The API will default to the UNFORMATTED format. ParameterFormat_PARAMETER_FORMAT_UNSPECIFIED ParameterFormat = 0 // Unformatted. ParameterFormat_UNFORMATTED ParameterFormat = 1 // YAML format. ParameterFormat_YAML ParameterFormat = 2 // JSON format. ParameterFormat_JSON ParameterFormat = 3 )
func (ParameterFormat) Descriptor ¶
func (ParameterFormat) Descriptor() protoreflect.EnumDescriptor
func (ParameterFormat) Enum ¶
func (x ParameterFormat) Enum() *ParameterFormat
func (ParameterFormat) EnumDescriptor
deprecated
func (ParameterFormat) EnumDescriptor() ([]byte, []int)
Deprecated: Use ParameterFormat.Descriptor instead.
func (ParameterFormat) Number ¶
func (x ParameterFormat) Number() protoreflect.EnumNumber
func (ParameterFormat) String ¶
func (x ParameterFormat) String() string
func (ParameterFormat) Type ¶
func (ParameterFormat) Type() protoreflect.EnumType
type ParameterManagerClient ¶
type ParameterManagerClient interface {
// Lists Parameters in a given project and location.
ListParameters(ctx context.Context, in *ListParametersRequest, opts ...grpc.CallOption) (*ListParametersResponse, error)
// Gets details of a single Parameter.
GetParameter(ctx context.Context, in *GetParameterRequest, opts ...grpc.CallOption) (*Parameter, error)
// Creates a new Parameter in a given project and location.
CreateParameter(ctx context.Context, in *CreateParameterRequest, opts ...grpc.CallOption) (*Parameter, error)
// Updates a single Parameter.
UpdateParameter(ctx context.Context, in *UpdateParameterRequest, opts ...grpc.CallOption) (*Parameter, error)
// Deletes a single Parameter.
DeleteParameter(ctx context.Context, in *DeleteParameterRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Lists ParameterVersions in a given project, location, and parameter.
ListParameterVersions(ctx context.Context, in *ListParameterVersionsRequest, opts ...grpc.CallOption) (*ListParameterVersionsResponse, error)
// Gets details of a single ParameterVersion.
GetParameterVersion(ctx context.Context, in *GetParameterVersionRequest, opts ...grpc.CallOption) (*ParameterVersion, error)
// Gets rendered version of a ParameterVersion.
RenderParameterVersion(ctx context.Context, in *RenderParameterVersionRequest, opts ...grpc.CallOption) (*RenderParameterVersionResponse, error)
// Creates a new ParameterVersion in a given project, location, and parameter.
CreateParameterVersion(ctx context.Context, in *CreateParameterVersionRequest, opts ...grpc.CallOption) (*ParameterVersion, error)
// Updates a single ParameterVersion.
UpdateParameterVersion(ctx context.Context, in *UpdateParameterVersionRequest, opts ...grpc.CallOption) (*ParameterVersion, error)
// Deletes a single ParameterVersion.
DeleteParameterVersion(ctx context.Context, in *DeleteParameterVersionRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
ParameterManagerClient is the client API for ParameterManager service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewParameterManagerClient ¶
func NewParameterManagerClient(cc grpc.ClientConnInterface) ParameterManagerClient
type ParameterManagerServer ¶
type ParameterManagerServer interface {
// Lists Parameters in a given project and location.
ListParameters(context.Context, *ListParametersRequest) (*ListParametersResponse, error)
// Gets details of a single Parameter.
GetParameter(context.Context, *GetParameterRequest) (*Parameter, error)
// Creates a new Parameter in a given project and location.
CreateParameter(context.Context, *CreateParameterRequest) (*Parameter, error)
// Updates a single Parameter.
UpdateParameter(context.Context, *UpdateParameterRequest) (*Parameter, error)
// Deletes a single Parameter.
DeleteParameter(context.Context, *DeleteParameterRequest) (*emptypb.Empty, error)
// Lists ParameterVersions in a given project, location, and parameter.
ListParameterVersions(context.Context, *ListParameterVersionsRequest) (*ListParameterVersionsResponse, error)
// Gets details of a single ParameterVersion.
GetParameterVersion(context.Context, *GetParameterVersionRequest) (*ParameterVersion, error)
// Gets rendered version of a ParameterVersion.
RenderParameterVersion(context.Context, *RenderParameterVersionRequest) (*RenderParameterVersionResponse, error)
// Creates a new ParameterVersion in a given project, location, and parameter.
CreateParameterVersion(context.Context, *CreateParameterVersionRequest) (*ParameterVersion, error)
// Updates a single ParameterVersion.
UpdateParameterVersion(context.Context, *UpdateParameterVersionRequest) (*ParameterVersion, error)
// Deletes a single ParameterVersion.
DeleteParameterVersion(context.Context, *DeleteParameterVersionRequest) (*emptypb.Empty, error)
}
ParameterManagerServer is the server API for ParameterManager service. All implementations should embed UnimplementedParameterManagerServer for forward compatibility
type ParameterVersion ¶
type ParameterVersion struct {
// Identifier. [Output only] The resource name of the ParameterVersion in the
// format `projects/*/locations/*/parameters/*/versions/*`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Output only. [Output only] Create time stamp
CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
// Output only. [Output only] Update time stamp
UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
// Optional. Disabled boolean to determine if a ParameterVersion acts as a
// metadata only resource (payload is never returned if disabled is true). If
// true any calls will always default to BASIC view even if the user
// explicitly passes FULL view as part of the request. A render call on a
// disabled resource fails with an error. Default value is False.
Disabled bool `protobuf:"varint,4,opt,name=disabled,proto3" json:"disabled,omitempty"`
// Required. Immutable. Payload content of a ParameterVersion resource. This
// is only returned when the request provides the View value of FULL (default
// for GET request).
Payload *ParameterVersionPayload `protobuf:"bytes,5,opt,name=payload,proto3" json:"payload,omitempty"`
// Optional. Output only. [Output only] The resource name of the KMS key
// version used to encrypt the ParameterVersion payload. This field is
// populated only if the Parameter resource has customer managed encryption
// key (CMEK) configured.
KmsKeyVersion *string `protobuf:"bytes,6,opt,name=kms_key_version,json=kmsKeyVersion,proto3,oneof" json:"kms_key_version,omitempty"`
// contains filtered or unexported fields
}
Message describing ParameterVersion resource
func (*ParameterVersion) Descriptor
deprecated
func (*ParameterVersion) Descriptor() ([]byte, []int)
Deprecated: Use ParameterVersion.ProtoReflect.Descriptor instead.
func (*ParameterVersion) GetCreateTime ¶
func (x *ParameterVersion) GetCreateTime() *timestamppb.Timestamp
func (*ParameterVersion) GetDisabled ¶
func (x *ParameterVersion) GetDisabled() bool
func (*ParameterVersion) GetKmsKeyVersion ¶ added in v0.2.0
func (x *ParameterVersion) GetKmsKeyVersion() string
func (*ParameterVersion) GetName ¶
func (x *ParameterVersion) GetName() string
func (*ParameterVersion) GetPayload ¶
func (x *ParameterVersion) GetPayload() *ParameterVersionPayload
func (*ParameterVersion) GetUpdateTime ¶
func (x *ParameterVersion) GetUpdateTime() *timestamppb.Timestamp
func (*ParameterVersion) ProtoMessage ¶
func (*ParameterVersion) ProtoMessage()
func (*ParameterVersion) ProtoReflect ¶
func (x *ParameterVersion) ProtoReflect() protoreflect.Message
func (*ParameterVersion) Reset ¶
func (x *ParameterVersion) Reset()
func (*ParameterVersion) String ¶
func (x *ParameterVersion) String() string
type ParameterVersionPayload ¶
type ParameterVersionPayload struct {
// Required. bytes data for storing payload.
Data []byte `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
Message for storing a ParameterVersion resource's payload data
func (*ParameterVersionPayload) Descriptor
deprecated
func (*ParameterVersionPayload) Descriptor() ([]byte, []int)
Deprecated: Use ParameterVersionPayload.ProtoReflect.Descriptor instead.
func (*ParameterVersionPayload) GetData ¶
func (x *ParameterVersionPayload) GetData() []byte
func (*ParameterVersionPayload) ProtoMessage ¶
func (*ParameterVersionPayload) ProtoMessage()
func (*ParameterVersionPayload) ProtoReflect ¶
func (x *ParameterVersionPayload) ProtoReflect() protoreflect.Message
func (*ParameterVersionPayload) Reset ¶
func (x *ParameterVersionPayload) Reset()
func (*ParameterVersionPayload) String ¶
func (x *ParameterVersionPayload) String() string
type RenderParameterVersionRequest ¶
type RenderParameterVersionRequest struct {
// Required. Name of the resource
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Message for getting a ParameterVersionRender
func (*RenderParameterVersionRequest) Descriptor
deprecated
func (*RenderParameterVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use RenderParameterVersionRequest.ProtoReflect.Descriptor instead.
func (*RenderParameterVersionRequest) GetName ¶
func (x *RenderParameterVersionRequest) GetName() string
func (*RenderParameterVersionRequest) ProtoMessage ¶
func (*RenderParameterVersionRequest) ProtoMessage()
func (*RenderParameterVersionRequest) ProtoReflect ¶
func (x *RenderParameterVersionRequest) ProtoReflect() protoreflect.Message
func (*RenderParameterVersionRequest) Reset ¶
func (x *RenderParameterVersionRequest) Reset()
func (*RenderParameterVersionRequest) String ¶
func (x *RenderParameterVersionRequest) String() string
type RenderParameterVersionResponse ¶
type RenderParameterVersionResponse struct {
// Output only. Resource identifier of a ParameterVersion in the format
// `projects/*/locations/*/parameters/*/versions/*`.
ParameterVersion string `protobuf:"bytes,1,opt,name=parameter_version,json=parameterVersion,proto3" json:"parameter_version,omitempty"`
// Payload content of a ParameterVersion resource.
Payload *ParameterVersionPayload `protobuf:"bytes,2,opt,name=payload,proto3" json:"payload,omitempty"`
// Output only. Server generated rendered version of the user provided payload
// data (ParameterVersionPayload) which has substitutions of all (if any)
// references to a SecretManager SecretVersion resources. This substitution
// only works for a Parameter which is in JSON or YAML format.
RenderedPayload []byte `protobuf:"bytes,3,opt,name=rendered_payload,json=renderedPayload,proto3" json:"rendered_payload,omitempty"`
// contains filtered or unexported fields
}
Message describing RenderParameterVersionResponse resource
func (*RenderParameterVersionResponse) Descriptor
deprecated
func (*RenderParameterVersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use RenderParameterVersionResponse.ProtoReflect.Descriptor instead.
func (*RenderParameterVersionResponse) GetParameterVersion ¶
func (x *RenderParameterVersionResponse) GetParameterVersion() string
func (*RenderParameterVersionResponse) GetPayload ¶
func (x *RenderParameterVersionResponse) GetPayload() *ParameterVersionPayload
func (*RenderParameterVersionResponse) GetRenderedPayload ¶
func (x *RenderParameterVersionResponse) GetRenderedPayload() []byte
func (*RenderParameterVersionResponse) ProtoMessage ¶
func (*RenderParameterVersionResponse) ProtoMessage()
func (*RenderParameterVersionResponse) ProtoReflect ¶
func (x *RenderParameterVersionResponse) ProtoReflect() protoreflect.Message
func (*RenderParameterVersionResponse) Reset ¶
func (x *RenderParameterVersionResponse) Reset()
func (*RenderParameterVersionResponse) String ¶
func (x *RenderParameterVersionResponse) String() string
type UnimplementedParameterManagerServer ¶
type UnimplementedParameterManagerServer struct {
}
UnimplementedParameterManagerServer should be embedded to have forward compatible implementations.
func (UnimplementedParameterManagerServer) CreateParameter ¶
func (UnimplementedParameterManagerServer) CreateParameter(context.Context, *CreateParameterRequest) (*Parameter, error)
func (UnimplementedParameterManagerServer) CreateParameterVersion ¶
func (UnimplementedParameterManagerServer) CreateParameterVersion(context.Context, *CreateParameterVersionRequest) (*ParameterVersion, error)
func (UnimplementedParameterManagerServer) DeleteParameter ¶
func (UnimplementedParameterManagerServer) DeleteParameter(context.Context, *DeleteParameterRequest) (*emptypb.Empty, error)
func (UnimplementedParameterManagerServer) DeleteParameterVersion ¶
func (UnimplementedParameterManagerServer) DeleteParameterVersion(context.Context, *DeleteParameterVersionRequest) (*emptypb.Empty, error)
func (UnimplementedParameterManagerServer) GetParameter ¶
func (UnimplementedParameterManagerServer) GetParameter(context.Context, *GetParameterRequest) (*Parameter, error)
func (UnimplementedParameterManagerServer) GetParameterVersion ¶
func (UnimplementedParameterManagerServer) GetParameterVersion(context.Context, *GetParameterVersionRequest) (*ParameterVersion, error)
func (UnimplementedParameterManagerServer) ListParameterVersions ¶
func (UnimplementedParameterManagerServer) ListParameterVersions(context.Context, *ListParameterVersionsRequest) (*ListParameterVersionsResponse, error)
func (UnimplementedParameterManagerServer) ListParameters ¶
func (UnimplementedParameterManagerServer) ListParameters(context.Context, *ListParametersRequest) (*ListParametersResponse, error)
func (UnimplementedParameterManagerServer) RenderParameterVersion ¶
func (UnimplementedParameterManagerServer) RenderParameterVersion(context.Context, *RenderParameterVersionRequest) (*RenderParameterVersionResponse, error)
func (UnimplementedParameterManagerServer) UpdateParameter ¶
func (UnimplementedParameterManagerServer) UpdateParameter(context.Context, *UpdateParameterRequest) (*Parameter, error)
func (UnimplementedParameterManagerServer) UpdateParameterVersion ¶
func (UnimplementedParameterManagerServer) UpdateParameterVersion(context.Context, *UpdateParameterVersionRequest) (*ParameterVersion, error)
type UnsafeParameterManagerServer ¶ added in v0.3.1
type UnsafeParameterManagerServer interface {
// contains filtered or unexported methods
}
UnsafeParameterManagerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ParameterManagerServer will result in compilation errors.
type UpdateParameterRequest ¶
type UpdateParameterRequest struct {
// Optional. Field mask is used to specify the fields to be overwritten in the
// Parameter resource by the update.
// The fields specified in the update_mask are relative to the resource, not
// the full request. A mutable field will be overwritten if it is in the
// mask. If the user does not provide a mask then all mutable fields present
// in the request will be overwritten.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,1,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// Required. The Parameter resource being updated
Parameter *Parameter `protobuf:"bytes,2,opt,name=parameter,proto3" json:"parameter,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique
// request ID so that if you must retry your request, the server will know to
// ignore the request if it has already been completed. The server will
// guarantee that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and the
// request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Message for updating a Parameter
func (*UpdateParameterRequest) Descriptor
deprecated
func (*UpdateParameterRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateParameterRequest.ProtoReflect.Descriptor instead.
func (*UpdateParameterRequest) GetParameter ¶
func (x *UpdateParameterRequest) GetParameter() *Parameter
func (*UpdateParameterRequest) GetRequestId ¶
func (x *UpdateParameterRequest) GetRequestId() string
func (*UpdateParameterRequest) GetUpdateMask ¶
func (x *UpdateParameterRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateParameterRequest) ProtoMessage ¶
func (*UpdateParameterRequest) ProtoMessage()
func (*UpdateParameterRequest) ProtoReflect ¶
func (x *UpdateParameterRequest) ProtoReflect() protoreflect.Message
func (*UpdateParameterRequest) Reset ¶
func (x *UpdateParameterRequest) Reset()
func (*UpdateParameterRequest) String ¶
func (x *UpdateParameterRequest) String() string
type UpdateParameterVersionRequest ¶
type UpdateParameterVersionRequest struct {
// Optional. Field mask is used to specify the fields to be overwritten in the
// ParameterVersion resource by the update.
// The fields specified in the update_mask are relative to the resource, not
// the full request. A mutable field will be overwritten if it is in the
// mask. If the user does not provide a mask then all mutable fields present
// in the request will be overwritten.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,1,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// Required. The ParameterVersion resource being updated
ParameterVersion *ParameterVersion `protobuf:"bytes,2,opt,name=parameter_version,json=parameterVersion,proto3" json:"parameter_version,omitempty"`
// Optional. An optional request ID to identify requests. Specify a unique
// request ID so that if you must retry your request, the server will know to
// ignore the request if it has already been completed. The server will
// guarantee that for at least 60 minutes since the first request.
//
// For example, consider a situation where you make an initial request and the
// request times out. If you make the request again with the same request
// ID, the server can check if original operation with the same request ID
// was received, and if so, will ignore the second request. This prevents
// clients from accidentally creating duplicate commitments.
//
// The request ID must be a valid UUID with the exception that zero UUID is
// not supported (00000000-0000-0000-0000-000000000000).
RequestId string `protobuf:"bytes,3,opt,name=request_id,json=requestId,proto3" json:"request_id,omitempty"`
// contains filtered or unexported fields
}
Message for updating a ParameterVersion
func (*UpdateParameterVersionRequest) Descriptor
deprecated
func (*UpdateParameterVersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateParameterVersionRequest.ProtoReflect.Descriptor instead.
func (*UpdateParameterVersionRequest) GetParameterVersion ¶
func (x *UpdateParameterVersionRequest) GetParameterVersion() *ParameterVersion
func (*UpdateParameterVersionRequest) GetRequestId ¶
func (x *UpdateParameterVersionRequest) GetRequestId() string
func (*UpdateParameterVersionRequest) GetUpdateMask ¶
func (x *UpdateParameterVersionRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateParameterVersionRequest) ProtoMessage ¶
func (*UpdateParameterVersionRequest) ProtoMessage()
func (*UpdateParameterVersionRequest) ProtoReflect ¶
func (x *UpdateParameterVersionRequest) ProtoReflect() protoreflect.Message
func (*UpdateParameterVersionRequest) Reset ¶
func (x *UpdateParameterVersionRequest) Reset()
func (*UpdateParameterVersionRequest) String ¶
func (x *UpdateParameterVersionRequest) String() string
type View ¶
type View int32
Option for requesting only metadata, or user provided payload of a ParameterVersion resource.
func (View) Descriptor ¶
func (View) Descriptor() protoreflect.EnumDescriptor
func (View) EnumDescriptor
deprecated
func (View) Number ¶
func (x View) Number() protoreflect.EnumNumber
func (View) Type ¶
func (View) Type() protoreflect.EnumType